package com.example.springdemo.utils;

import lombok.*;
import org.jetbrains.annotations.Contract;
import org.jetbrains.annotations.NotNull;

import java.io.Serializable;

@NoArgsConstructor
@AllArgsConstructor
@Getter
@Setter
public class Result<T> implements Serializable {
    private Integer status = 0;
    private String message = "";
    private T data;

    public Result(Integer status, String message) {
        this.status = status;
        this.message = message;
    }

    public Result(Integer status) {
        this.status = status;
    }

    @Contract("_, _, _ -> new")
    public static <T> @NotNull Result<T> of(Integer status, String message, T data) {
        return new Result<>(status, message, data);
    }

    @Contract(value = "_, _ -> new", pure = true)
    public static <T> @NotNull Result<T> of(Integer status, String message) {
        return Result.of(status, message, null);
    }
}
