package com.example.springdemo.utils;

import com.example.springdemo.entities.Users;
import jakarta.servlet.http.HttpServletRequest;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import java.lang.reflect.Method;

//角色权限控制AOP
@Component
@Aspect
public class RoleVerificationAspect {
    @Pointcut("@annotation(com.example.springdemo.utils.RoleVerificationAnnotation)")
    public void roleVerification() {
    }

    @Around("roleVerification()")
    public Object around(@NotNull ProceedingJoinPoint joinPoint) throws Throwable {
        Signature signature = joinPoint.getSignature();
        MethodSignature methodSignature = (MethodSignature) signature;
        // 获取正在访问的方法
        Method executingMethod = methodSignature.getMethod();
        RequestAttributes requestAttributes = RequestContextHolder.getRequestAttributes();
        ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes) requestAttributes;
        Object result;
        String message = "Permission denied";
        if (executingMethod.getReturnType().getTypeName().contains(Result.class.getSimpleName())) {
            result = Result.of(404, message);
        } else {
            result = message;
        }

        if (servletRequestAttributes == null) {
            return result;
        }
        HttpServletRequest request = servletRequestAttributes.getRequest();
        Integer userID = null;
        Integer roleID = null;
        //RolesPermissions rolesPermissions = (RolesPermissions) request.getSession().getAttribute("rolesPermissions");
        Users users = (Users) request.getSession().getAttribute("users");
        if (users != null) {
            userID = users.getId().intValue();
            roleID = users.getRoles().getId().intValue();
        }
        RoleVerificationAnnotation roleVerificationAnnotation = executingMethod.getAnnotation(RoleVerificationAnnotation.class);
        //获取注解中的types字段
        long[] rolesIdList = roleVerificationAnnotation.RoleIDList();
        long[] userIdList = roleVerificationAnnotation.UserIDList();
        //判断是否有权限访问
        boolean hasPermission = false;
        //是否需要进行校验，如果注解中的types为空，即用户列表和角色列表同时为空，则不进行校验
        boolean needVerify = rolesIdList.length != 0 || userIdList.length != 0;
        if (needVerify) {
            for (long roleId : rolesIdList) {
                if (roleID != null && roleID == roleId) {
                    hasPermission = true;
                    break;
                }
            }
            for (long userId : userIdList) {
                if (userID != null && userID == userId) {
                    hasPermission = true;
                    break;
                }
            }
        } else {
            hasPermission = true;
        }

        if (hasPermission) {
            result = joinPoint.proceed();
        }

        return result;
    }
}
